@@ -1,17 +1,19 @@
 import copy
-import uuid
 
 from django.core.exceptions import ObjectDoesNotExist, FieldDoesNotExist
 from django.db import models
 from factory import SubFactory
 
+from w.django import utils
 from w.tests.helpers import date_test_helper
 
 
 class DataTestFactory:
     def __init__(self):
-        self.data_repository = dict()
-        self.factory_repository = list()
+        self.data_repository = {}
+        self.snapshot_repository = {}
+        self._snapshot = None
+        self.factory_repository = []
         self._today_is = "2015-09-03 11:15:00"
 
     def _factory_reset_sequence(self, facto, value=None):
@@ -54,7 +56,8 @@ class DataTestFactory:
             # création à plus tard, quand l'objet serait trouvé
             return self.get_by_ref(use_data_ref)
 
-        return self._load_data(data_def)
+        created_models, snapshots = self._load_data(data_def)
+        return created_models
         # on pourra ensuite passer cet objet à l'objet en cours pour création
 
     @staticmethod
@@ -109,14 +112,18 @@ class DataTestFactory:
             create_datas.update(**fk_relations)
 
         created = factory_class(**create_datas)
+        snapshot = utils.model_to_dict(created)
 
         # si on a poppé des relations inverses, il faut alors passer l'objet crée, à
         # l'étage du dessous pour création car certaines sont non nullables
         if many2many_relations:
             for fieldname, value in many2many_relations.items():
-                self._load_data(value, fieldname=fieldname, related_object=created)
+                _, many2many_snapshot = self._load_data(
+                    value, fieldname=fieldname, related_object=created
+                )
+                snapshot[fieldname] = copy.deepcopy(many2many_snapshot)
 
-        return created
+        return created, snapshot
 
     def _parse_and_create_object(self, data_def, fieldname=None, parent_model=None):
         # si l'objet à créer est un callable, on se pose pas de question, on call
@@ -124,12 +131,16 @@ class DataTestFactory:
         use_data_ref = obj_to_create.pop("data_ref", None)
 
         if "factory" in obj_to_create:
-            data = self._create_by_factory(obj_to_create, fieldname, parent_model)
+            data, snapshot = self._create_by_factory(
+                obj_to_create, fieldname, parent_model
+            )
         elif use_data_ref:
             data = self.get_by_ref(use_data_ref)
+            snapshot = self._get_snapshot_by_ref(use_data_ref)
         elif "from_db" in data_def:
             db_data = data_def.pop("from_db", None)
             data = self._get_from_db(**db_data)
+            snapshot = utils.model_to_dict(data)
         else:
             raise RuntimeError(
                 f"factory not found for {obj_to_create} or missing data_ref"
@@ -137,12 +148,15 @@ class DataTestFactory:
 
         if parent_model and self._is_many2many_field(parent_model, fieldname):
             getattr(parent_model, fieldname).add(data)
+        return data, snapshot
 
-        return data
+    def _add_to_snapshot_repository(self, data_ref, snapshot):
+        self.snapshot_repository.update({data_ref: snapshot})
+
+    def _get_snapshot_by_ref(self, data_ref):
+        return self.snapshot_repository.get(data_ref, None)
 
     def _add_to_data_repository(self, data_ref=None, data_content=None):
-        if data_ref is None:
-            data_ref = uuid.uuid4()
         self.data_repository.update({data_ref: data_content})
 
     def get_by_ref(self, data_ref):
@@ -175,23 +189,31 @@ class DataTestFactory:
         data_occurrence = data_def.pop("nb", 1)
         data_ref = data_def.pop("ref", None)
         created_objects = []
+        snapshots = []
         for cpt in range(0, data_occurrence):
             # on doit travailler sur une copie, pour pouvoir pop tranquillement les
             # valeurs spéciales, plusieurs fois.
-            created_object = self._parse_and_create_object(
+            created_object, snapshot = self._parse_and_create_object(
                 data_def, many2many_key, fk_object
             )
-            unique_data_ref = self._get_unique_data_ref(data_ref, cpt + 1)
-            self._add_to_data_repository(unique_data_ref, created_object)
+            if data_ref:
+                unique_data_ref = self._get_unique_data_ref(data_ref, cpt + 1)
+                self._add_to_data_repository(unique_data_ref, created_object)
+                self._add_to_snapshot_repository(unique_data_ref, snapshot)
             created_objects.append(created_object)
-        return created_objects if data_occurrence > 1 else created_objects[0]
+            snapshots.append(snapshot)
+        if data_occurrence > 1:
+            return created_objects, snapshots
+        return created_objects[0], snapshots[0]
 
     def _load_list_data(self, data_def, many2many_key, fk_object):
         created = []
+        snapshots = []
         for data in data_def:
-            created_object = self._load_data(data, many2many_key, fk_object)
+            created_object, snapshot = self._load_data(data, many2many_key, fk_object)
             created.append(created_object)
-        return created
+            snapshots.append(copy.deepcopy(snapshot))
+        return created, snapshots
 
     def _load_data(self, data_def, fieldname=None, related_object=None):
         # besoin de faire une copie dans le cas ou les définitions de datas
@@ -224,4 +246,8 @@ class DataTestFactory:
             data_def_copy = data_def.copy()
             if nb and nb > 0:
                 data_def_copy["nb"] = nb
-            return self._load_data(data_def_copy)
+            created_objects, self._snapshot = self._load_data(data_def_copy)
+        return created_objects
+
+    def built_snapshots(self):
+        return {k: v for k, v in self.snapshot_repository.items()}
