@@ -1,6 +1,27 @@
 from django import urls
 from django.utils.translation import gettext
 
+from django.db import models
+from django.db.models.fields.related import ManyToManyField, ForeignKey
+
+
+# noinspection PyUnresolvedReferences,PyProtectedMember
+def model_to_dict(model: models.Model):
+    if hasattr(model, "_meta") is False:
+        return None
+    opts = model._meta
+    data = {}
+    for f in opts.concrete_fields + opts.many_to_many:
+        if isinstance(f, ForeignKey):
+            fk = getattr(model, f.name)
+            data[f.name] = model_to_dict(getattr(model, f.name)) if fk else None
+            continue
+        if isinstance(f, ManyToManyField):
+            data[f.name] = [model_to_dict(m) for m in f.value_from_object(model)]
+            continue
+        data[f.name] = f.value_from_object(model)
+    return data
+
 
 def reverse(
     viewname, urlconf=None, args=None, kwargs=None, current_app=None, query_kwargs=None
