@@ -55,9 +55,7 @@ class AbstractModelService(AbstractService):
     def get_if_exists(cls, **filters):
         """Retrieve instance if exists else return None"""
         qs = cls._model.objects.filter(**filters)
-        if qs.exists():
-            return qs.first()
-        return None
+        return qs.first()
 
     @classmethod
     def is_exists_by_pk(cls, pk) -> bool:
