@@ -5,6 +5,7 @@ from pathlib import Path
 from typing import Union
 
 from w.services.abstract_service import AbstractService
+from w.services.technical.date_service import DateService
 
 
 class FilesystemService(AbstractService):
@@ -48,11 +49,11 @@ class FilesystemService(AbstractService):
             None if directory exists
 
         Raises:
-            RuntimeError if directory does not exists
+            RuntimeError if directory does not exist
         """
         if cls.is_dir_exists(directory):
             return None
-        raise RuntimeError(f"{directory} does not exists")
+        raise RuntimeError(f"{directory} does not exist")
 
     @classmethod
     def check_file_exists(cls, filename) -> None:
@@ -229,3 +230,17 @@ class FilesystemService(AbstractService):
         if not isinstance(suffix, list):
             suffix = [suffix]
         return filename.suffix in suffix
+
+    @staticmethod
+    def prefix_filename_to_now(filename):
+        """
+        Add timestamp as prefix to the provided filename.
+        Timestamp is set to current date and time.
+
+        Args:
+            filename(str):
+
+        Returns:
+            filename with prefix
+        """
+        return f"{DateService.to_str('YYYYMMDD_HHmmss')}-{filename}"
