@@ -27,3 +27,8 @@ class ListService(AbstractService):
         elements from list2 are not in list1
         """
         return not cls.are_same(list1, list2)
+
+    @classmethod
+    def convert_elements_to_string(cls, list1):
+        """ Convert elements in list into string """
+        return [str(i) for i in list1]
