@@ -1,8 +1,6 @@
 from w.django.tests.django_testcase import DjangoTestCase
 from w.services.technical.date_service import DateService
-from w.tests.fixtures.datasets.builders.builder_with_auto_now import (
-    BuilderWithAutoNow,
-)
+from w.tests.fixtures.datasets.builders.builder_with_auto_now import BuilderWithAutoNow
 from w.tests.fixtures.datasets.builders.builder_with_internal_dependencies import (
     BuilderWithInternalDependencies,
     InternalDependencyOneTestBuilder,
